:mod:`exspy.signals`
--------------------

.. currentmodule:: exspy.signals


.. autosummary::
   DielectricFunction
   EDSSpectrum
   EDSTEMSpectrum
   EELSSpectrum
   EDSSEMSpectrum

.. autosummary::
   LazyDielectricFunction
   LazyEDSSpectrum
   LazyEDSSEMSpectrum
   LazyEDSTEMSpectrum
   LazyEELSSpectrum


.. automodule:: exspy.signals
   :members:
